### Name: flowFrame-class
### Title: 'flowFrame': a class for storing observed quantitative
###   properties for a population of cells from a FACS run
### Aliases: flowFrame-class flowFrame [,flowFrame,ANY-method
###   [,flowFrame,filter-method [,flowFrame,filterResult-method $.flowFrame
###   exprs exprs<- exprs,flowFrame-method exprs<-,flowFrame,matrix-method
###   exprs<-,flowFrame,ANY-method initialize,flowFrame-method
###   head,flowFrame-method tail,flowFrame-method description
###   description,flowFrame-method description<-,flowFrame,list-method
###   description<-,flowFrame,ANY-method show,flowFrame-method
###   plot,flowFrame,ANY-method plot,flowFrame-method
###   summary,flowFrame-method ncol ncol,flowFrame-method nrow
###   nrow,flowFrame-method dim dim,flowFrame-method featureNames
###   featureNames,flowFrame-method colnames colnames,flowFrame-method
###   colnames<- colnames<-,flowFrame-method names names,flowFrame-method
###   range range,flowFrame-method cbind2,flowFrame,matrix-method
###   cbind2,flowFrame,numeric-method transform,flowFrame-method
###   compensate,flowFrame,matrix-method
###   compensate,flowFrame,data.frame-method
###   compensate,flowFrame,compensation-method
###   ==,flowFrame,filterResult-method ==,flowFrame,flowFrame-method
###   <,flowFrame,ANY-method <=,flowFrame,ANY-method >,flowFrame,ANY-method
###   >=,flowFrame,ANY-method spillover,flowFrame-method
### Keywords: classes

### ** Examples


## load example data
data(GvHD)
frame <- GvHD[[1]]

## subsetting
frame[1:4,]
frame[,3]
frame[,"FSC-H"]
frame$"SSC-H"

## accessing and replacing raw values
head(exprs(frame))
exprs(frame) <- exprs(frame)[1:3000,]
frame
exprs(frame) <- exprs(frame)[,1:6]
frame

## access FCS keywords
head(description(frame))
keyword(frame, c("FILENAME", "$FIL"))

## parameter annotation
parameters(frame)
pData(parameters(frame))

## summarize frame data
summary(frame)

## plotting
plot(frame)
if(require(flowViz)){
plot(frame)
plot(frame, c("FSC-H", "SSC-H"))
plot(frame[,1])
plot(frame, c("FSC-H", "SSC-H"), smooth=FALSE)
}

## frame dimensions
ncol(frame)
nrow(frame)
dim(frame)

## accessing and replacing parameter names
featureNames(frame)
all(featureNames(frame) == colnames(frame))
colnames(frame) <- make.names(colnames(frame))
colnames(frame)
parameters(frame)$name
names(frame)

## accessing a GUID
identifier(frame)
identifier(frame) <- "test"

## dynamic range of a frame
range(frame)
range(frame, "FSC.H", "FL1.H")
range(frame)$FSC.H

## iterators
head(each_row(frame, mean))
head(each_col(frame, mean))

## transformation
opar <- par(mfcol=c(1:2))
if(require(flowViz))
plot(frame, c("FL1.H", "FL2.H"))
frame <- transform(frame, FL1.H=log(`FL1.H`), FL2.H=log(`FL2.H`))
if(require(flowViz))
plot(frame, c("FL1.H", "FL2.H"))
par(opar)
range(frame)

## filtering of flowFrames
rectGate <- rectangleGate(filterId="nonDebris","FSC.H"=c(200,Inf))
fres <- filter(frame, rectGate)
summary(fres)

## splitting of flowFrames
split(frame, rectGate)
split(frame, rectGate, flowSet=TRUE)
split(frame, fres)
f <- cut(exprs(frame$FSC.H), 3)
split(frame, f)

## subsetting according to filters and filter results
Subset(frame, rectGate)
Subset(frame, fres)
Subset(frame, as.logical(exprs(frame$FSC.H) < 300))
frame[rectGate,]
frame[fres,]

## accessing the spillover matrix
try(spillover(frame))

## check equality
frame2 <- frame
frame == frame2
exprs(frame2) <- exprs(frame)*2
frame == frame2




