### Name: flowSet-class
### Title: 'flowSet': a class for storing flow cytometry raw data from
###   quantitative cell-based assays
### Aliases: flowSet-class flowSet [,flowSet-method [,flowSet,ANY-method
###   $,flowSet,character-method [[,flowSet-method [[,flowSet,ANY-method
###   [[<-,flowSet-method [[<-,flowSet,ANY,ANY,flowFrame-method
###   [[<-,flowFrame-method fsApply,flowSet-method show,flowSet-method
###   length,flowSet-method colnames,flowSet-method
###   colnames<-,flowSet-method identifier,flowSet-method
###   identifier<-,flowSet,ANY-method compensate,flowSet,ANY-method
###   sampleNames,flowSet-method sampleNames<-,flowSet,ANY-method
###   phenoData,flowSet-method phenoData<-,flowSet,ANY-method
###   phenoData<-,flowSet,phenoData-method pData,flowSet-method
###   pData<-,flowSet,data.frame-method plot,flowSet,ANY-method
###   plot,flowSet-method varLabels,flowSet-method
###   varLabels<-,flowSet-method varLabels<-,flowSet,ANY-method
###   varMetadata,flowSet-method varMetadata<-,flowSet,ANY-method
###   compensate,flowSet,matrix-method transform,flowSet-method
###   rbind2,flowSet,missing rbind2,flowSet,flowSet-method
###   rbind2,flowSet,flowSet,missing-method rbind2,flowSet,flowFrame-method
###   rbind2,flowFrame,flowSet-method rbind2,flowSet,missing-method
###   summary,flowSet-method
### Keywords: classes

### ** Examples


## load example data and object creation
data(GvHD)

## subsetting to flowSet
set <- GvHD[1:4]
GvHD[1:4,1:2]
sel <- sampleNames(GvHD)[1:2]
GvHD[sel, "FSC-H"]
GvHD[sampleNames(GvHD) == sel[1], colnames(GvHD[1]) == "SSC-H"]

## subsetting to flowFrame
GvHD[[1]]
GvHD[[1, 1:3]]
GvHD[[1, "FSC-H"]]
GvHD[[1, colnames(GvHD[1]) == "SSC-H"]]
GvHD$s5a02

## constructor
flowSet(GvHD[[1]], GvHD[[2]])
pd <- phenoData(GvHD)[1:2,]
flowSet(s5a01=GvHD[[1]], s5a02=GvHD[[2]],phenoData=pd)

## colnames
colnames(set)
colnames(set) <- make.names(colnames(set))

## object name
identifier(set)
identifier(set) <- "test"

## phenoData
pd <- phenoData(set)
pd
pd$test <- "test"
phenoData(set) <- pd
pData(set)
varLabels(set)
varLabels(set)[6] <- "Foo"
varLabels(set)

## sampleNames
sampleNames(set)
sampleNames(set) <- LETTERS[1:length(set)]
sampleNames(set)

## keywords
keyword(set, list("transformation"))

## length
length(set)

## compensation
samp <- read.flowSet(path=system.file("extdata","compdata","data",
package="flowCore"))
cfile <- system.file("extdata","compdata","compmatrix", package="flowCore")
comp.mat <- read.table(cfile, header=TRUE, skip=2, check.names = FALSE)
comp.mat
summary(samp[[1]])
samp <- compensate(samp, as.matrix(comp.mat))
summary(samp[[1]])

## transformation
opar <- par(mfcol=c(1:2))
plot(set[[1]], c("FL1.H", "FL2.H"))
set <- transform(set, FL1.H=log(FL1.H), FL2.H=log(FL2.H))
plot(set[[1]], c("FL1.H", "FL2.H"))
par(opar)

## filtering of flowSets
rectGate <- rectangleGate(filterId="nonDebris", FSC.H=c(200,Inf))
fres <- filter(set, rectGate)
class(fres)
summary(fres[[1]])
rectGate2 <- rectangleGate(filterId="nonDebris2", SSC.H=c(300,Inf))
fres2 <- filter(set, list(A=rectGate, B=rectGate2, C=rectGate, D=rectGate2))

## Splitting frames of a flowSet
split(set, rectGate)
split(set[1:2], rectGate, populatiuon="nonDebris2+")
split(set, c(1,1,2,2))

## subsetting according to filters and filter results
Subset(set, rectGate)
Subset(set, filter(set, rectGate))
Subset(set, list(A=rectGate, B=rectGate2, C=rectGate, D=rectGate2))

## combining flowSets
rbind2(set[1:2], set[3:4])
rbind2(set[1:3], set[[4]])
rbind2(set[[4]], set[1:2])




